==> dnet-actionmanager-common-6.0.3-20170622.161909-23-sources.jar: eu/dnetlib/actionmanager/actions/AtomicActionDeserialiser.java <==
package eu.dnetlib.actionmanager.actions;

import java.lang.reflect.Type;

import com.google.gson.*;
import com.googlecode.protobuf.format.JsonFormat;
import eu.dnetlib.actionmanager.common.Agent;
import eu.dnetlib.data.proto.OafProtos;
import eu.dnetlib.miscutils.functional.hash.Hashing;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Created by claudio on 30/09/15.
 */
public class AtomicActionDeserialiser extends AbstractActionSerializer implements JsonDeserializer<AtomicAction> {

	private static final Log log = LogFactory.getLog(AtomicActionDeserialiser.class);

	@Override
	public AtomicAction deserialize(final JsonElement json, final Type typeOfT, final JsonDeserializationContext context) throws JsonParseException {

		if (json.isJsonObject()) {
			final JsonObject j = (JsonObject) json;

			final Agent a = new Agent();

			final JsonObject aj = j.get(agent).getAsJsonObject();
			a.setId(aj.get(agent_id).getAsString());
			a.setName(aj.get(agent_name).getAsString());
			a.setType(Agent.AGENT_TYPE.valueOf(aj.get(agent_type).getAsString()));

			AtomicAction aa = new AtomicAction(j.get(rawSet).getAsString(), a);

			aa.setTargetColumn(j.get(targetColumn).getAsString());
			aa.setTargetColumnFamily(j.get(targetColumnFamily).getAsString());
			aa.setTargetRowKey(j.get(targetRowKey).getAsString());

			aa.setRowKey(j.get(rowKey).getAsString());
			aa.setTargetValue(decodeTargetValue(j.get(targetValue).getAsString()));

			return aa;

		}

		throw new JsonParseException("input is not a json object");
	}

	private byte[] decodeTargetValue(final String s) {
		try {
			final String json = Hashing.decodeBase64(s);

			OafProtos.Oaf.Builder oaf = OafProtos.Oaf.newBuilder();
			JsonFormat.merge(json, oaf);

			return oaf.build().toByteArray();
		} catch (JsonFormat.ParseException e) {
			log.error("unable to parse proto", e);
			return null;
		}
	}

}

==> dnet-actionmanager-common-6.0.8-20240424.153713-6-sources.jar: eu/dnetlib/actionmanager/actions/AtomicActionDeserialiser.java <==
package eu.dnetlib.actionmanager.actions;

import java.lang.reflect.Type;
import java.nio.charset.Charset;

import com.google.gson.*;
import com.googlecode.protobuf.format.JsonFormat;
import eu.dnetlib.actionmanager.common.Agent;
import eu.dnetlib.data.proto.OafProtos;
import eu.dnetlib.miscutils.functional.hash.Hashing;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import static org.apache.commons.lang3.StringUtils.*;

/**
 * Created by claudio on 30/09/15.
 */
public class AtomicActionDeserialiser extends AbstractActionSerializer implements JsonDeserializer<AtomicAction> {

	private static final Log log = LogFactory.getLog(AtomicActionDeserialiser.class);

	private final static byte[] EMPTY = "".getBytes(Charset.forName("UTF-8"));

	@Override
	public AtomicAction deserialize(final JsonElement json, final Type typeOfT, final JsonDeserializationContext context) throws JsonParseException {

		if (json.isJsonObject()) {
			final JsonObject j = (JsonObject) json;

			final Agent a = new Agent();

			final JsonObject aj = j.get(agent).getAsJsonObject();
			a.setId(aj.get(agent_id).getAsString());
			a.setName(aj.get(agent_name).getAsString());
			a.setType(Agent.AGENT_TYPE.valueOf(aj.get(agent_type).getAsString()));

			AtomicAction aa = new AtomicAction(j.get(rawSet).getAsString(), a);

			aa.setTargetColumn(j.get(targetColumn).getAsString());
			aa.setTargetColumnFamily(j.get(targetColumnFamily).getAsString());
			aa.setTargetRowKey(j.get(targetRowKey).getAsString());

			aa.setRowKey(j.get(rowKey).getAsString());
			aa.setTargetValue(decodeTargetValue(j.get(targetValue).getAsString()));

			return aa;

		}

		throw new JsonParseException("input is not a json object");
	}

	private byte[] decodeTargetValue(final String s) throws JsonParseException {
		if (isBlank(s)) {
			return EMPTY;
		}

		try {
			final String json = Hashing.decodeBase64(s);

			OafProtos.Oaf.Builder oaf = OafProtos.Oaf.newBuilder();
			JsonFormat.merge(json, oaf);

			return oaf.build().toByteArray();
		} catch (JsonFormat.ParseException e) {
			throw new JsonParseException("unable to parse proto", e);
		}
	}

}
